@@ -5,7 +5,8 @@
 #'
 #' @param con A database connection object created by DBI::dbConnect or any
 #'   similar function that establishes a connection to a database.
-#' @return A logical value: `TRUE` if disconnection was successful, `FALSE`
+#'
+#' @returns A logical value: `TRUE` if disconnection was successful, `FALSE`
 #'   otherwise.
 #'
 #' @export
@@ -13,7 +14,5 @@ disconnection_connection <- function(con) {
 
   check_if_package_installed("DBI", "wrds_*")
 
-  dbDisconnect <- getNamespace("DBI")$dbDisconnect
-
-  dbDisconnect(con)
+  DBI::dbDisconnect(con)
 }
