@@ -12,18 +12,20 @@
 #'   format.
 #' @param end_date The end date for filtering the data, in "YYYY-MM-DD" format.
 #'
-#' @return A tibble with processed factor data, including dates, risk-free
+#' @returns A tibble with processed factor data, including dates, risk-free
 #'   rates, market excess returns, and other factors, filtered by the specified
 #'   date range.
 #'
+#' @export
 #' @examples
 #' \donttest{
-#'   download_data_factors("factors_ff3_monthly", "2000-01-01", "2020-12-31")
+#'   download_data_factors("factors_ff_3_monthly", "2000-01-01", "2020-12-31")
+#'   download_data_factors("factors_ff_3_daily")
 #'   download_data_factors("factors_q5_daily", "2020-01-01", "2020-12-31")
 #' }
-#'
-#' @export
-download_data_factors <- function(type, start_date, end_date) {
+download_data_factors <- function(
+    type, start_date, end_date
+  ) {
 
   check_supported_type(type)
 
@@ -40,71 +42,84 @@ download_data_factors <- function(type, start_date, end_date) {
 #' Download and Process Fama-French Factor Data
 #'
 #' Downloads and processes Fama-French factor data based on the specified type
-#' (e.g., "factors_ff3_monthly"), and date range. The function first checks if
+#' (e.g., "factors_ff_3_monthly"), and date range. The function first checks if
 #' the specified type is supported and requires the 'frenchdata' package to
 #' download the data. It processes the raw data into a structured format,
 #' including date conversion, scaling factor values, and filtering by the
 #' specified date range.
 #'
+#' If there are multiple tables in the raw Fama-French data (e.g., value-weighted
+#' and equal-weighted returns), then the function only returns the first table
+#' because these are the most popular. Please use the `frenchdata` package
+#' directly if you need less commonly used tables.
+#'
 #' @param type The type of dataset to download, corresponding to the specific
 #'   Fama-French model and frequency.
-#' @param start_date The start date for filtering the data, in "YYYY-MM-DD"
-#'   format.
-#' @param end_date The end date for filtering the data, in "YYYY-MM-DD" format.
+#' @param start_date Optional. A character string or Date object in "YYYY-MM-DD" format
+#'   specifying the start date for the data. If not provided, the full dataset is returned.
+#' @param end_date Optional. A character string or Date object in "YYYY-MM-DD" format
+#'   specifying the end date for the data. If not provided, the full dataset is returned.
 #'
-#' @return A tibble with processed factor data, including the date, risk-free
+#' @returns A tibble with processed factor data, including the date, risk-free
 #'   rate, market excess return, and other factors, filtered by the specified
 #'   date range.
 #'
+#' @export
 #' @examples
 #' \donttest{
-#'   download_data_factors_ff("factors_ff3_monthly", "2000-01-01", "2020-12-31")
-#'   download_data_factors_ff("factors_ff_industry_10_monthly", "2000-01-01", "2020-12-31")
+#'   download_data_factors_ff("factors_ff_3_monthly", "2000-01-01", "2020-12-31")
+#'   download_data_factors_ff("factors_ff_10_industry_portfolios_monthly", "2000-01-01", "2020-12-31")
 #' }
-#'
-#' @import dplyr
-#' @importFrom lubridate ymd floor_date
-#'
-#' @export
-download_data_factors_ff <- function(type, start_date, end_date) {
+download_data_factors_ff <- function(
+    type, start_date, end_date
+  ) {
 
   check_supported_type(type)
 
   check_if_package_installed("frenchdata", type)
 
-  download_french_data <- getNamespace("frenchdata")$download_french_data
-
-  start_date <- as.Date(start_date)
-  end_date <- as.Date(end_date)
+  if (missing(start_date) || missing(end_date)) {
+    message("No start_date or end_date provided. Returning the full data set.")
+  } else {
+    start_date <- as.Date(start_date)
+    end_date <- as.Date(end_date)
+  }
 
   factors_ff_types <- list_supported_types_ff()
   dataset <- factors_ff_types$dataset_name[factors_ff_types$type == type]
 
-  raw_data <- suppressMessages(download_french_data(dataset))
+  raw_data <- suppressMessages(frenchdata::download_french_data(dataset))
   raw_data <- raw_data$subsets$data[[1]]
 
   if (grepl("monthly", type, fixed = TRUE)) {
     processed_data <- raw_data |>
-      mutate(date = lubridate::floor_date(lubridate::ymd(paste0(date, "01")), "month"))
-  } else {
+      mutate(date = floor_date(ymd(paste0(date, "01")), "month"))
+  } else if (grepl("daily|weekly", type)) {
     processed_data <- raw_data |>
-      mutate(date = lubridate::ymd(date))
+      mutate(date = ymd(date))
+  } else {
+    stop("This data type has neither daily, weekly, nor monthly frequency.")
   }
 
+  # Transform column values
   processed_data <- processed_data |>
     mutate(
       across(-date, ~na_if(.,-99.99)),
+      across(-date, ~na_if(., -999)),
       across(-date, ~ . / 100)
-    ) |>
-    rename_with(tolower) |>
-    filter(between(date, start_date, end_date))
+    )
 
-  processed_data <- if (grepl("industry", type, fixed = TRUE)) {
-    processed_data |>
-      select(date, everything())
-  } else {
-    processed_data |>
-      select(date, risk_free = rf, mkt_excess = `mkt-rf`, everything())
+  # Clean column names
+  colnames_clean <- colnames(processed_data) |>
+    tolower() |>
+    gsub("-rf", "_excess", x = _) |>
+    gsub("rf", "risk_free", x = _)
+
+  colnames(processed_data) <- colnames_clean
+
+  if (!missing(start_date) && !missing(end_date)) {
+    processed_data <- processed_data |>
+      filter(between(date, start_date, end_date))
   }
 
   processed_data
@@ -121,33 +136,34 @@ download_data_factors_ff <- function(type, start_date, end_date) {
 #'
 #' @param type The type of dataset to download (e.g., "factors_q5_daily",
 #'   "factors_q5_monthly").
-#' @param start_date The start date for filtering the data, in "YYYY-MM-DD"
-#'   format.
-#' @param end_date The end date for filtering the data, in "YYYY-MM-DD" format.
+#' @param start_date Optional. A character string or Date object in "YYYY-MM-DD" format
+#'   specifying the start date for the data. If not provided, the full dataset is returned.
+#' @param end_date Optional. A character string or Date object in "YYYY-MM-DD" format
+#'   specifying the end date for the data. If not provided, the full dataset is returned.
 #' @param url The base URL from which to download the dataset files, with a
 #'   specific path for Global Q datasets.
 #'
-#' @return A tibble with processed factor data, including the date, risk-free
+#' @returns A tibble with processed factor data, including the date, risk-free
 #'   rate, market excess return, and other factors, filtered by the specified
 #'   date range.
 #'
+#' @export
 #' @examples
 #' \donttest{
 #'   download_data_factors_q("factors_q5_daily", "2020-01-01", "2020-12-31")
 #' }
-#'
-#' @import dplyr
-#' @importFrom lubridate ymd
-#' @importFrom utils read.csv
-#'
-#' @export
 download_data_factors_q <- function(
     type, start_date, end_date, url = "http://global-q.org/uploads/1/2/2/6/122679606/"
 ) {
 
   check_supported_type(type)
-  start_date <- as.Date(start_date)
-  end_date <- as.Date(end_date)
+
+  if (missing(start_date) || missing(end_date)) {
+    message("No start_date or end_date provided. Returning the full data set.")
+  } else {
+    start_date <- as.Date(start_date)
+    end_date <- as.Date(end_date)
+  }
 
   factors_q_types <- list_supported_types_q()
   dataset <- factors_q_types$dataset_name[factors_q_types$type == type]
@@ -155,20 +171,24 @@ download_data_factors_q <- function(
 
   if (grepl("monthly", type, fixed = TRUE)) {
     processed_data <- raw_data |>
-      mutate(date = lubridate::ymd(paste(year, month, "01", sep = "-"))) |>
+      mutate(date = ymd(paste(year, month, "01", sep = "-"))) |>
       select(-c(year, month))
   }
   if (grepl("daily", type, fixed = TRUE)) {
     processed_data <- raw_data |>
-      mutate(DATE = lubridate::ymd(DATE))
+      mutate(DATE = ymd(DATE))
   }
 
   processed_data <- processed_data |>
     rename_with(~sub("R_", "", ., fixed = TRUE)) |>
     rename_with(tolower) |>
     mutate(across(-date, ~. / 100)) |>
-    filter(between(date, start_date, end_date)) |>
     select(date, risk_free = f, mkt_excess = mkt, everything())
 
+  if (!missing(start_date) && !missing(end_date)) {
+    processed_data <- processed_data |>
+      filter(between(date, start_date, end_date))
+  }
+
   processed_data
 }
