@@ -16,11 +16,13 @@
 #' @param min_obs The minimum number of observations required to estimate the
 #'   model. Defaults to 1.
 #'
-#' @return If a single independent variable is specified, a numeric value
+#' @returns If a single independent variable is specified, a numeric value
 #'   representing the coefficient of that variable. If multiple independent
 #'   variables are specified, a data frame with a row for each coefficient and
 #'   column names corresponding to the independent variables.
 #'
+#' @seealso \code{\link[stats]{lm}} for details on the underlying linear model fitting used.
+#' @export
 #' @examples
 #' data <- data.frame(
 #'   ret_excess = rnorm(100),
@@ -33,12 +35,6 @@
 #'
 #' # Estimate model with multiple independent variables
 #' multi_var_model <- estimate_model(data, "ret_excess ~ mkt_excess + smb + hml")
-#'
-#' @export
-#'
-#' @importFrom stats setNames lm as.formula coefficients
-#'
-#' @seealso \code{\link[stats]{lm}} for details on the underlying linear model fitting used.
 estimate_model <- function(data, model, min_obs = 1) {
   model_parts <- strsplit(model, "~", fixed = TRUE)[[1]]
   response_var <- trimws(model_parts[1])
@@ -46,7 +42,8 @@ estimate_model <- function(data, model, min_obs = 1) {
   independent_vars <- independent_vars[independent_vars != ""]
 
   if (nrow(data) < min_obs) {
-    beta <- stats::setNames(as.numeric(rep(NA, length(independent_vars))), independent_vars)
+    beta <- setNames(as.numeric(rep(NA, length(independent_vars))),
+                     independent_vars)
     if (length(beta) == 1) {
       return(NA_real_)
     } else {
