@@ -9,24 +9,21 @@
 #'   distribution. For example, a `cut` of 0.05 will winsorize the lowest and
 #'   highest 5% of the data. Must be inside \[0, 0.5\].
 #'
-#' @return A numeric vector with the extreme values replaced by the
+#' @returns A numeric vector with the extreme values replaced by the
 #'   corresponding quantile values.
 #'
+#' @export
 #' @examples
 #' set.seed(123)
 #' data <- rnorm(100)
 #' winsorized_data <- winsorize(data, 0.05)
-#'
-#' @importFrom stats quantile
-#'
-#' @export
 winsorize <- function(x, cut) {
   if (cut < 0 || cut > 0.5) {
     stop("The parameter 'cut' must be inside [0, 0.5].")
   }
 
-  lb <- stats::quantile(x, cut, na.rm = TRUE)
-  up <- stats::quantile(x, 1 - cut, na.rm = TRUE)
+  lb <- quantile(x, cut, na.rm = TRUE)
+  up <- quantile(x, 1 - cut, na.rm = TRUE)
   x <- replace(x, x > up, up)
   x <- replace(x, x < lb, lb)
   x
